/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */

/* gnome-xgl-settings.c
 * Copyright (C) 2006 Novell, Inc.
 *
 * Written by: Radek Doulik <rodo@novell.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
 * 02111-1307, USA.
 */

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <string.h>

#include <glib.h>
#include <glib/gi18n.h>
#include <gtk/gtkcheckbutton.h>
#include <gtk/gtkicontheme.h>
#include <gtk/gtkmessagedialog.h>
#include <gtk/gtkmain.h>
#include <libgnome/gnome-help.h>
#include <libgnome/gnome-util.h>
#include <libgnomeui/gnome-ui-init.h>

#include "gnome-xgl-settings.h"

GladeXML *glade;
GConfClient *gconf;
GtkTooltips *tooltips;

/* c'n'pasted (and modified) from control-center */
static void
set_window_icon (GtkWidget *window, char const *icon_file_name)
{
	char *basename;
	char *p;
	GdkPixbuf *icon_pixbuf = NULL;
	GtkIconTheme *icon_theme;
	GtkIconInfo  *icon_info;

	/* First look up from the icon theme */
	icon_theme = gtk_icon_theme_get_default ();

	basename = g_path_get_basename (icon_file_name);
	p = strrchr (basename, '.');
	if (p)
		p[0] = '\0';

	icon_info = gtk_icon_theme_lookup_icon (icon_theme, basename, 48, 0);
	if (icon_info != NULL) {
		icon_pixbuf = gtk_icon_info_load_icon (icon_info, NULL);
		gtk_icon_info_free (icon_info);
	}
	g_free (basename);

	if (icon_pixbuf == NULL)
		icon_pixbuf = gdk_pixbuf_new_from_file (icon_file_name, NULL);

	if (icon_pixbuf != NULL) {
		/* Make sure that every window gets an icon */
		gtk_window_set_default_icon (icon_pixbuf);

		gtk_window_set_icon (GTK_WINDOW (window), icon_pixbuf);

		g_object_unref (icon_pixbuf);
	}
}

static void
response_cb (GtkWidget *dialog_win,
	     int	response_id)
{
	if (response_id == GTK_RESPONSE_HELP)
		visit_wiki ();
	else
		gtk_widget_destroy (dialog_win);
}

void
notebook_switch_page (GtkNotebook *notebook,
		      GtkNotebookPage *page, guint page_num)
{
	gtk_widget_set_sensitive (GXGL_WIDGET ("help_button"),
				  page_num == 0);
}

int
main (int argc, char **argv)
{
	GtkWidget *dialog_win;

	bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
	bind_textdomain_codeset(GETTEXT_PACKAGE, "UTF-8");
	textdomain (GETTEXT_PACKAGE);

  	gnome_program_init ("gnome-xgl-settings", VERSION,
			    LIBGNOMEUI_MODULE, argc, argv,
			    NULL, NULL, NULL);

	gconf = gconf_client_get_default ();
	gconf_client_add_dir (gconf, "/apps/compiz", GCONF_CLIENT_PRELOAD_NONE, NULL);

	glade = glade_xml_new (GLADEDIR "/gnome-xgl-settings.glade",
			       "prefs", GETTEXT_PACKAGE);
	if (glade == NULL) {
		g_warning ("Missing glade file for gnome-xgl-settings");
		exit (1);
	}
	glade_xml_signal_autoconnect (glade);

	tooltips = gtk_tooltips_new ();

	dialog_win = GXGL_WIDGET ("prefs");

	setup_switch_page ();
	plugins_init ();
	setup_settings_pages ();

	g_signal_connect (G_OBJECT (dialog_win), "response",
			  G_CALLBACK (response_cb), NULL);

	g_signal_connect (G_OBJECT (dialog_win), "destroy",
			  G_CALLBACK (gtk_main_quit), NULL);

	set_window_icon (dialog_win, ICONDIR "/xgl-settings-capplet.svg");
	gtk_widget_show (dialog_win);
	
	gtk_main ();

	return 0;
}
