/* -*- Mode: C; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 8 -*- */

/* Copyright (C) 2006 Novell, Inc.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
 * 02111-1307, USA.
 */

#ifndef __GNOME_XGL_SETTINGS_H__
#define __GNOME_XGL_SETTINGS_H__

#include <math.h>
#include <stdlib.h>
#include <string.h>

#include <gconf/gconf-client.h>
#include <glade/glade.h>
#include <gtk/gtk.h>
#include <glib/gi18n.h>

#include "keybinding.h"

extern GladeXML *glade;
extern GConfClient *gconf;
extern GtkTooltips *tooltips;

#define GXGL_WIDGET(name) ((gpointer)glade_xml_get_widget (glade, (name)))

void setup_switch_page (void);
void visit_wiki (void);

void setup_settings_pages (void);

void plugins_init (void);
gboolean plugins_activate (const char *plugin, ...) G_GNUC_NULL_TERMINATED;
gboolean plugins_deactivate (const char *plugin, ...) G_GNUC_NULL_TERMINATED;
gboolean plugin_active (const char *plugin);
gboolean plugin_required (const char *plugin);
void free_slist (GSList *slist);

/* prototypes for glade autoconnected signal handlers */
void notebook_switch_page (GtkNotebook *notebook, GtkNotebookPage *page, guint page_num);

gboolean eventbox_button_press_event (GtkWidget *widget, GdkEventButton *event,
                                      gpointer user_data);
void switch_button_clicked (GtkButton *button, gpointer user_data);

void wobbly_windows_toggled (GtkToggleButton *toggle, gpointer user_data);
void wobbly_snap_modifier_toggled (GtkToggleButton *toggle, gpointer user_data);
void wobbly_snap_toggled (GtkToggleButton *toggle, gpointer user_data);
void translucent_move_toggled (GtkToggleButton *toggle, gpointer user_data);
void wobbly_map_toggled (GtkToggleButton *toggle, gpointer user_data);
void wobbly_focus_toggled (GtkToggleButton *toggle, gpointer user_data);
void fade_toggled (GtkToggleButton *toggle, gpointer user_data);
void minimize_toggled (GtkToggleButton *toggle, gpointer user_data);
void opacity_modifier_toggled (GtkToggleButton *toggle, gpointer user_data);
void opacity_toggled (GtkToggleButton *toggle, gpointer user_data);
void cube_toggled (GtkToggleButton *toggle, gpointer user_data);
void cube_size_value_changed (GtkSpinButton *spin, gpointer user_data);
void cube_drag_modifier_toggled (GtkToggleButton *toggle, gpointer user_data);
void cube_drag_toggled (GtkToggleButton *toggle, gpointer user_data);
void edge_flip_toggled (GtkToggleButton *toggle, gpointer user_data);
void edge_flip_delay_value_changed (GtkRange *range, gpointer user_data);
void scale_key_changed (GXGLKeybinding *widget, const char *binding);
void scale_key_size_allocate (GtkWidget *widget, GtkAllocation *allocation, gpointer user_data);
void scale_corner_changed (GtkComboBox *combo, gpointer user_data);
void scale_enable_corner_toggled (GtkToggleButton *toggle, gpointer user_data);
void zoom_modifier_toggled (GtkToggleButton *toggle, gpointer user_data);
void zoom_toggled (GtkToggleButton *toggle, gpointer user_data);
void zoom_scroll_modifier_toggled (GtkToggleButton *toggle, gpointer user_data);
void zoom_scroll_toggled (GtkToggleButton *toggle, gpointer user_data);
void water_modifier_toggled (GtkToggleButton *toggle, gpointer user_data);
void water_toggled (GtkToggleButton *toggle, gpointer user_data);
void rain_key_changed (GXGLKeybinding *widget, const char *binding);
void rain_rate_value_changed (GtkRange *range, gpointer user_data);

/* GConf keys */
#define KEY_ACTIVE_PLUGINS		"/apps/compiz/general/allscreens/options/active_plugins"
#define KEY_WOBBLY_MOVE_WINDOW_TYPES	"/apps/compiz/plugins/wobbly/screen0/options/move_window_types"
#define KEY_WOBBLY_SNAP 		"/apps/compiz/plugins/wobbly/allscreens/options/snap_key"
#define KEY_MOVE_OPACITY		"/apps/compiz/plugins/move/allscreens/options/opacity"
#define KEY_WOBBLY_MAP_EFFECT		"/apps/compiz/plugins/wobbly/screen0/options/map_effect"
#define KEY_WOBBLY_MAP_WINDOW_TYPES	"/apps/compiz/plugins/wobbly/screen0/options/map_window_types"
#define KEY_WOBBLY_FOCUS_EFFECT		"/apps/compiz/plugins/wobbly/screen0/options/focus_effect"
#define KEY_WOBBLY_FOCUS_WINDOW_TYPES	"/apps/compiz/plugins/wobbly/screen0/options/focus_window_types"
#define KEY_OPACITY_INCREASE		"/apps/compiz/general/allscreens/options/opacity_increase_button"
#define KEY_OPACITY_DECREASE		"/apps/compiz/general/allscreens/options/opacity_decrease_button"
#define KEY_CUBE_SIZE   		"/apps/compiz/general/screen0/options/hsize"
#define KEY_CUBE_DRAG           	"/apps/compiz/plugins/rotate/allscreens/options/initiate_button"
#define KEY_ROTATE_EDGE_FLIP_POINTER	"/apps/compiz/plugins/rotate/allscreens/options/edge_flip_pointer"
#define KEY_ROTATE_EDGE_FLIP_MOVE	"/apps/compiz/plugins/rotate/allscreens/options/edge_flip_move"
#define KEY_ROTATE_EDGE_FLIP_DND	"/apps/compiz/plugins/rotate/allscreens/options/edge_flip_dnd"
#define KEY_ROTATE_FLIP_TIME		"/apps/compiz/plugins/rotate/allscreens/options/flip_time"
#define KEY_SCALE_INITIATE		"/apps/compiz/plugins/scale/allscreens/options/initiate_key"
#define KEY_SCALE_CORNERS		"/apps/compiz/plugins/scale/allscreens/options/initiate_edge"
#define KEY_ZOOM_INITIATE		"/apps/compiz/plugins/zoom/allscreens/options/initiate_button"
#define KEY_ZOOM_IN                     "/apps/compiz/plugins/zoom/allscreens/options/zoom_in_button"
#define KEY_ZOOM_OUT    		"/apps/compiz/plugins/zoom/allscreens/options/zoom_out_button"
#define KEY_WATER_INITIATE		"/apps/compiz/plugins/water/allscreens/options/initiate_button"
#define KEY_RAIN_TOGGLE 		"/apps/compiz/plugins/water/allscreens/options/toggle_rain_key"
#define KEY_RAIN_DELAY          	"/apps/compiz/plugins/water/allscreens/options/rain_delay"

#endif /* __GNOME_XGL_SETTINGS_H__ */
